@@ -3,6 +3,7 @@ import os
 # CI
 rpc = """
 # client.py
+!pip install Pyro4
 import Pyro4 
 uri = "PYRONAME:factorial.server" # Get the URI of the server object from the name  server 
 factorial_server = Pyro4.Proxy(uri) 
@@ -71,6 +72,7 @@ server.serve_forever()
 
 rmi = """
 # client2.py
+!pip install Pyro4
 import Pyro4
 
 def main():
@@ -113,6 +115,8 @@ python client2.py
 """
 
 mapreduce_character_count = """
+!pip install mrjob
+
 # character_count.py
 from mrjob.job import MRJob
 import sys
@@ -165,6 +169,10 @@ if __name__ == '__main__':
 Dr D y Patil Institute Of Engineering Management And Research , Akurdi
 
 ##############################################################
+
+### To run
+python3 .\character_count.py x.txt
+python3 .\word_count.py x.txt
 """
 
 fuzzy_sets_u_n = """
@@ -580,7 +588,7 @@ print("Classification Report:")
 print(classification_report(y_test, y_pred))
 """
 
-art_neural_style_transfer = """
+art_neural_style_transfer_1 = """
 !pip install tensorflow
 
 import tensorflow as tf
@@ -673,6 +681,74 @@ plt.axis('off')
 plt.show()
 """
 
+art_neural_style_transfer_2 = """
+import os
+import tensorflow as tf
+# Load compressed models from tensorflow_hub
+os.environ['TFHUB_MODEL_LOAD_FORMAT'] = 'COMPRESSED'
+
+import IPython.display as display
+
+import matplotlib.pyplot as plt
+import matplotlib as mpl
+mpl.rcParams['figure.figsize'] = (12, 12)
+mpl.rcParams['axes.grid'] = False
+
+import numpy as np
+import PIL.Image
+import time
+import functools
+
+def tensor_to_image(tensor):
+  tensor = tensor*255
+  tensor = np.array(tensor, dtype=np.uint8)
+  if np.ndim(tensor)>3:
+    assert tensor.shape[0] == 1
+    tensor = tensor[0]
+  return PIL.Image.fromarray(tensor)
+
+content_path = tf.keras.utils.get_file('YellowLabradorLooking_new.jpg', 'https://storage.googleapis.com/download.tensorflow.org/example_images/YellowLabradorLooking_new.jpg')
+style_path = tf.keras.utils.get_file('kandinsky5.jpg','https://storage.googleapis.com/download.tensorflow.org/example_images/Vassily_Kandinsky%2C_1913_-_Composition_7.jpg')
+
+def load_img(path_to_img):
+  max_dim = 512
+  img = tf.io.read_file(path_to_img)
+  img = tf.image.decode_image(img, channels=3)
+  img = tf.image.convert_image_dtype(img, tf.float32)
+
+  shape = tf.cast(tf.shape(img)[:-1], tf.float32)
+  long_dim = max(shape)
+  scale = max_dim / long_dim
+
+  new_shape = tf.cast(shape * scale, tf.int32)
+
+  img = tf.image.resize(img, new_shape)
+  img = img[tf.newaxis, :]
+  return img
+
+def imshow(image, title=None):
+  if len(image.shape) > 3:
+    image = tf.squeeze(image, axis=0)
+
+  plt.imshow(image)
+  if title:
+    plt.title(title)
+
+content_image = load_img(content_path)
+style_image = load_img(style_path)
+
+plt.subplot(1, 2, 1)
+imshow(content_image, 'Content Image')
+
+plt.subplot(1, 2, 2)
+imshow(style_image, 'Style Image')
+
+import tensorflow_hub as hub
+hub_model = hub.load('https://tfhub.dev/google/magenta/arbitrary-image-stylization-v1-256/2')
+stylized_image = hub_model(tf.constant(content_image), tf.constant(style_image))[0]
+tensor_to_image(stylized_image)
+"""
+
 masterDict = {
     "rpc": rpc,
     "rmi": rmi,
@@ -683,7 +759,8 @@ masterDict = {
     "Deap": Deap,
     "ant_colony": ant_colony,
     "arti_immune_pr_damage_class": arti_immune_pr_damage_class,
-    "arti_immune_pr_damage_class": arti_immune_pr_damage_class,
+    "art_neural_style_transfer_1": art_neural_style_transfer_1,
+    "art_neural_style_transfer_2": art_neural_style_transfer_2
 }
 
 
